@@ -2,22 +2,22 @@ from enum import Enum
 from typing import Union
 
 
-class AddTask:
+class AddProcess:
 
-    def __init__(self, task_uuid: str, _type: str = ''):
-        self._type = 'add_task'
-        self.task_uuid = task_uuid
+    def __init__(self, process_uuid: str, _type: str = ''):
+        self._type = 'add_process'
+        self.process_uuid = process_uuid
 
     def __eq__(self, other: object) -> bool:
-        if isinstance(other, AddTask):
-            return other.task_uuid == self.task_uuid
+        if isinstance(other, AddProcess):
+            return other.process_uuid == self.process_uuid
         return False
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"<task_uuid={self.task_uuid}>"
+        return f"<process_uuid={self.process_uuid}>"
 
 
 class Destination(Enum):
@@ -34,16 +34,16 @@ class Destination(Enum):
             raise NotImplementedError
 
 
-class MoveOperation:
+class MoveTask:
 
-    def __init__(self, operation_uuid: str, destination: Union[str, Destination], _type: str = ''):
-        self._type = 'move_operation'
-        self.operation_uuid = operation_uuid
+    def __init__(self, task_uuid: str, destination: Union[str, Destination], _type: str = ''):
+        self._type = 'move_task'
+        self.task_uuid = task_uuid
         self.destination = destination if type(destination) == Destination else Destination.from_str(destination)
 
     def __eq__(self, other: object) -> bool:
-        if isinstance(other, MoveOperation):
-            return other.operation_uuid == self.operation_uuid and \
+        if isinstance(other, MoveTask):
+            return other.task_uuid == self.task_uuid and \
                    other.destination == self.destination
         return False
 
@@ -51,37 +51,37 @@ class MoveOperation:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"<operation_uuid={self.operation_uuid},destination={self.destination}>"
+        return f"<task_uuid={self.task_uuid},destination={self.destination}>"
 
 
-class CompleteOperation:
+class CompleteTask:
 
-    def __init__(self, operation_uuid: str, _type: str = ''):
-        self._type = 'complete_operation'
-        self.operation_uuid = operation_uuid
+    def __init__(self, task_uuid: str, _type: str = ''):
+        self._type = 'complete_task'
+        self.task_uuid = task_uuid
 
     def __eq__(self, other: object) -> bool:
-        if isinstance(other, CompleteOperation):
-            return other.operation_uuid == self.operation_uuid
+        if isinstance(other, CompleteTask):
+            return other.task_uuid == self.task_uuid
         return False
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"<operation_uuid={self.operation_uuid}>"
+        return f"<task_uuid={self.task_uuid}>"
 
 
 class ConfirmNeeded:
 
-    def __init__(self, operation_uuid: str, confirm_needed: bool, _type: str = ''):
+    def __init__(self, task_uuid: str, confirm_needed: bool, _type: str = ''):
         self._type = 'confirm_needed'
-        self.operation_uuid = operation_uuid
+        self.task_uuid = task_uuid
         self.confirm_needed = confirm_needed
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, ConfirmNeeded):
-            return other.operation_uuid == self.operation_uuid \
+            return other.task_uuid == self.task_uuid \
                    and other.confirm_needed == self.confirm_needed
         return False
 
@@ -89,4 +89,4 @@ class ConfirmNeeded:
         return not self.__eq__(other)
 
     def __repr__(self):
-        return f"<operation_uuid={self.operation_uuid},confirm_needed={self.confirm_needed}>"
+        return f"<task_uuid={self.task_uuid},confirm_needed={self.confirm_needed}>"
